@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -110,6 +113,42 @@ class ImageAnnotatorAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ImageAnnotatorClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ImageAnnotatorTransport:
         """Returns the transport used by the client instance.
@@ -182,6 +221,24 @@ class ImageAnnotatorAsyncClient:
         r"""Run image detection and annotation for a batch of
         images.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            async def sample_batch_annotate_images():
+                # Create a client
+                client = vision_v1.ImageAnnotatorAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.BatchAnnotateImagesRequest(
+                )
+
+                # Make the request
+                response = await client.batch_annotate_images(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.BatchAnnotateImagesRequest, dict]):
                 The request object. Multiple image annotation requests
@@ -206,7 +263,7 @@ class ImageAnnotatorAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -241,7 +298,12 @@ class ImageAnnotatorAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -264,6 +326,24 @@ class ImageAnnotatorAsyncClient:
         perform detection and annotation for each image
         extracted.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            async def sample_batch_annotate_files():
+                # Create a client
+                client = vision_v1.ImageAnnotatorAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.BatchAnnotateFilesRequest(
+                )
+
+                # Make the request
+                response = await client.batch_annotate_files(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.BatchAnnotateFilesRequest, dict]):
                 The request object. A list of requests to annotate files
@@ -288,7 +368,7 @@ class ImageAnnotatorAsyncClient:
                 A list of file annotation responses.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -323,7 +403,12 @@ class ImageAnnotatorAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -351,6 +436,28 @@ class ImageAnnotatorAsyncClient:
         in customer GCS bucket, each json file containing
         BatchAnnotateImagesResponse proto.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            async def sample_async_batch_annotate_images():
+                # Create a client
+                client = vision_v1.ImageAnnotatorAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.AsyncBatchAnnotateImagesRequest(
+                )
+
+                # Make the request
+                operation = client.async_batch_annotate_images(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateImagesRequest, dict]):
                 The request object. Request for async image annotation
@@ -385,7 +492,7 @@ class ImageAnnotatorAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests, output_config])
         if request is not None and has_flattened_params:
@@ -422,7 +529,12 @@ class ImageAnnotatorAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -452,6 +564,28 @@ class ImageAnnotatorAsyncClient:
         (metadata). ``Operation.response`` contains
         ``AsyncBatchAnnotateFilesResponse`` (results).
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            async def sample_async_batch_annotate_files():
+                # Create a client
+                client = vision_v1.ImageAnnotatorAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.AsyncBatchAnnotateFilesRequest(
+                )
+
+                # Make the request
+                operation = client.async_batch_annotate_files(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateFilesRequest, dict]):
                 The request object. Multiple async file annotation
@@ -479,7 +613,7 @@ class ImageAnnotatorAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -514,7 +648,12 @@ class ImageAnnotatorAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -536,7 +675,9 @@ class ImageAnnotatorAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-vision",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-vision",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
