@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -54,7 +56,10 @@ class ImageAnnotatorClientMeta(type):
     _transport_registry["grpc"] = ImageAnnotatorGrpcTransport
     _transport_registry["grpc_asyncio"] = ImageAnnotatorGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[ImageAnnotatorTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[ImageAnnotatorTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -163,10 +168,16 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return self._transport
 
     @staticmethod
-    def product_path(project: str, location: str, product: str,) -> str:
+    def product_path(
+        project: str,
+        location: str,
+        product: str,
+    ) -> str:
         """Returns a fully-qualified product string."""
         return "projects/{project}/locations/{location}/products/{product}".format(
-            project=project, location=location, product=product,
+            project=project,
+            location=location,
+            product=product,
         )
 
     @staticmethod
@@ -179,10 +190,18 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def product_set_path(project: str, location: str, product_set: str,) -> str:
+    def product_set_path(
+        project: str,
+        location: str,
+        product_set: str,
+    ) -> str:
         """Returns a fully-qualified product_set string."""
-        return "projects/{project}/locations/{location}/productSets/{product_set}".format(
-            project=project, location=location, product_set=product_set,
+        return (
+            "projects/{project}/locations/{location}/productSets/{product_set}".format(
+                project=project,
+                location=location,
+                product_set=product_set,
+            )
         )
 
     @staticmethod
@@ -195,7 +214,9 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -208,9 +229,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -219,9 +244,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -230,9 +259,13 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -241,10 +274,14 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -253,6 +290,73 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -303,50 +407,22 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, ImageAnnotatorTransport):
             # transport is a ImageAnnotatorTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -358,6 +434,15 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -368,6 +453,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def batch_annotate_images(
@@ -382,6 +468,24 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         r"""Run image detection and annotation for a batch of
         images.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            def sample_batch_annotate_images():
+                # Create a client
+                client = vision_v1.ImageAnnotatorClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.BatchAnnotateImagesRequest(
+                )
+
+                # Make the request
+                response = client.batch_annotate_images(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.BatchAnnotateImagesRequest, dict]):
                 The request object. Multiple image annotation requests
@@ -406,7 +510,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -434,7 +538,12 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.batch_annotate_images]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -457,6 +566,24 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         perform detection and annotation for each image
         extracted.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            def sample_batch_annotate_files():
+                # Create a client
+                client = vision_v1.ImageAnnotatorClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.BatchAnnotateFilesRequest(
+                )
+
+                # Make the request
+                response = client.batch_annotate_files(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.BatchAnnotateFilesRequest, dict]):
                 The request object. A list of requests to annotate files
@@ -481,7 +608,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
                 A list of file annotation responses.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -509,7 +636,12 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.batch_annotate_files]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -537,6 +669,28 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         in customer GCS bucket, each json file containing
         BatchAnnotateImagesResponse proto.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            def sample_async_batch_annotate_images():
+                # Create a client
+                client = vision_v1.ImageAnnotatorClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.AsyncBatchAnnotateImagesRequest(
+                )
+
+                # Make the request
+                operation = client.async_batch_annotate_images(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateImagesRequest, dict]):
                 The request object. Request for async image annotation
@@ -571,7 +725,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests, output_config])
         if request is not None and has_flattened_params:
@@ -603,7 +757,12 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         ]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -633,6 +792,28 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         (metadata). ``Operation.response`` contains
         ``AsyncBatchAnnotateFilesResponse`` (results).
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1
+
+            def sample_async_batch_annotate_files():
+                # Create a client
+                client = vision_v1.ImageAnnotatorClient()
+
+                # Initialize request argument(s)
+                request = vision_v1.AsyncBatchAnnotateFilesRequest(
+                )
+
+                # Make the request
+                operation = client.async_batch_annotate_files(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1.types.AsyncBatchAnnotateFilesRequest, dict]):
                 The request object. Multiple async file annotation
@@ -660,7 +841,7 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([requests])
         if request is not None and has_flattened_params:
@@ -690,7 +871,12 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
         ]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -719,7 +905,9 @@ class ImageAnnotatorClient(metaclass=ImageAnnotatorClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-vision",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-vision",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
