@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -106,7 +106,9 @@ from .text_annotation import (
     TextAnnotation,
     Word,
 )
-from .web_detection import WebDetection
+from .web_detection import (
+    WebDetection,
+)
 
 __all__ = (
     "BoundingPoly",
