@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,11 @@ import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.vision.v1p1beta1",
-    manifest={"Vertex", "BoundingPoly", "Position",},
+    manifest={
+        "Vertex",
+        "BoundingPoly",
+        "Position",
+    },
 )
 
 
@@ -34,8 +38,14 @@ class Vertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.INT32, number=1,)
-    y = proto.Field(proto.INT32, number=2,)
+    x = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    y = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class BoundingPoly(proto.Message):
@@ -46,7 +56,11 @@ class BoundingPoly(proto.Message):
             The bounding polygon vertices.
     """
 
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
+    vertices = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Vertex",
+    )
 
 
 class Position(proto.Message):
@@ -64,9 +78,18 @@ class Position(proto.Message):
             Z coordinate (or depth).
     """
 
-    x = proto.Field(proto.FLOAT, number=1,)
-    y = proto.Field(proto.FLOAT, number=2,)
-    z = proto.Field(proto.FLOAT, number=3,)
+    x = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    y = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    z = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
