@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,10 @@ import proto  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.vision.v1p2beta1", manifest={"WebDetection",},
+    package="google.cloud.vision.v1p2beta1",
+    manifest={
+        "WebDetection",
+    },
 )
 
 
@@ -61,9 +64,18 @@ class WebDetection(proto.Message):
                 English.
         """
 
-        entity_id = proto.Field(proto.STRING, number=1,)
-        score = proto.Field(proto.FLOAT, number=2,)
-        description = proto.Field(proto.STRING, number=3,)
+        entity_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        score = proto.Field(
+            proto.FLOAT,
+            number=2,
+        )
+        description = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
     class WebImage(proto.Message):
         r"""Metadata for online images.
@@ -76,8 +88,14 @@ class WebDetection(proto.Message):
                 image.
         """
 
-        url = proto.Field(proto.STRING, number=1,)
-        score = proto.Field(proto.FLOAT, number=2,)
+        url = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        score = proto.Field(
+            proto.FLOAT,
+            number=2,
+        )
 
     class WebPage(proto.Message):
         r"""Metadata for web pages.
@@ -102,14 +120,27 @@ class WebDetection(proto.Message):
                 crops.
         """
 
-        url = proto.Field(proto.STRING, number=1,)
-        score = proto.Field(proto.FLOAT, number=2,)
-        page_title = proto.Field(proto.STRING, number=3,)
+        url = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        score = proto.Field(
+            proto.FLOAT,
+            number=2,
+        )
+        page_title = proto.Field(
+            proto.STRING,
+            number=3,
+        )
         full_matching_images = proto.RepeatedField(
-            proto.MESSAGE, number=4, message="WebDetection.WebImage",
+            proto.MESSAGE,
+            number=4,
+            message="WebDetection.WebImage",
         )
         partial_matching_images = proto.RepeatedField(
-            proto.MESSAGE, number=5, message="WebDetection.WebImage",
+            proto.MESSAGE,
+            number=5,
+            message="WebDetection.WebImage",
         )
 
     class WebLabel(proto.Message):
@@ -124,23 +155,45 @@ class WebDetection(proto.Message):
                 http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
         """
 
-        label = proto.Field(proto.STRING, number=1,)
-        language_code = proto.Field(proto.STRING, number=2,)
+        label = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        language_code = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
-    web_entities = proto.RepeatedField(proto.MESSAGE, number=1, message=WebEntity,)
+    web_entities = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=WebEntity,
+    )
     full_matching_images = proto.RepeatedField(
-        proto.MESSAGE, number=2, message=WebImage,
+        proto.MESSAGE,
+        number=2,
+        message=WebImage,
     )
     partial_matching_images = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=WebImage,
+        proto.MESSAGE,
+        number=3,
+        message=WebImage,
     )
     pages_with_matching_images = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=WebPage,
+        proto.MESSAGE,
+        number=4,
+        message=WebPage,
     )
     visually_similar_images = proto.RepeatedField(
-        proto.MESSAGE, number=6, message=WebImage,
+        proto.MESSAGE,
+        number=6,
+        message=WebImage,
+    )
+    best_guess_labels = proto.RepeatedField(
+        proto.MESSAGE,
+        number=8,
+        message=WebLabel,
     )
-    best_guess_labels = proto.RepeatedField(proto.MESSAGE, number=8, message=WebLabel,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
