@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -135,6 +138,42 @@ class ProductSearchAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ProductSearchClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ProductSearchTransport:
         """Returns the transport used by the client instance.
@@ -213,6 +252,25 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if display_name is missing, or is
            longer than 4096 characters.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_create_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.CreateProductSetRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = await client.create_product_set(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.CreateProductSetRequest, dict]):
                 The request object. Request message for the
@@ -257,7 +315,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, product_set, product_set_id])
         if request is not None and has_flattened_params:
@@ -299,7 +357,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -320,6 +383,26 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if page_size is greater than 100, or
            less than 1.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_list_product_sets():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.ListProductSetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_product_sets(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.ListProductSetsRequest, dict]):
                 The request object. Request message for the
@@ -348,7 +431,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -389,12 +472,20 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProductSetsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -415,6 +506,25 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the ProductSet does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_get_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.GetProductSetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_product_set(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.GetProductSetRequest, dict]):
                 The request object. Request message for the
@@ -444,7 +554,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -485,7 +595,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -510,6 +625,24 @@ class ProductSearchAsyncClient:
            update_mask but missing from the request or longer than 4096
            characters.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_update_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.UpdateProductSetRequest(
+                )
+
+                # Make the request
+                response = await client.update_product_set(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.UpdateProductSetRequest, dict]):
                 The request object. Request message for the
@@ -546,7 +679,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([product_set, update_mask])
         if request is not None and has_flattened_params:
@@ -588,7 +721,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -612,6 +750,22 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the ProductSet does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_delete_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.DeleteProductSetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                await client.delete_product_set(request=request)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.DeleteProductSetRequest, dict]):
                 The request object. Request message for the
@@ -632,7 +786,7 @@ class ProductSearchAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -674,7 +828,10 @@ class ProductSearchAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def create_product(
@@ -699,6 +856,25 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if product_category is missing or
            invalid.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_create_product():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.CreateProductRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = await client.create_product(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.CreateProductRequest, dict]):
                 The request object. Request message for the
@@ -738,7 +914,7 @@ class ProductSearchAsyncClient:
                 A Product contains ReferenceImages.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, product, product_id])
         if request is not None and has_flattened_params:
@@ -780,7 +956,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -801,6 +982,26 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if page_size is greater than 100 or
            less than 1.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_list_products():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.ListProductsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_products(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.ListProductsRequest, dict]):
                 The request object. Request message for the
@@ -829,7 +1030,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -870,12 +1071,20 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProductsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -896,6 +1105,25 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the Product does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_get_product():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.GetProductRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_product(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.GetProductRequest, dict]):
                 The request object. Request message for the `GetProduct`
@@ -920,7 +1148,7 @@ class ProductSearchAsyncClient:
                 A Product contains ReferenceImages.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -961,7 +1189,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -993,6 +1226,24 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if product_category is present in
            update_mask.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_update_product():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.UpdateProductRequest(
+                )
+
+                # Make the request
+                response = await client.update_product(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.UpdateProductRequest, dict]):
                 The request object. Request message for the
@@ -1026,7 +1277,7 @@ class ProductSearchAsyncClient:
                 A Product contains ReferenceImages.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([product, update_mask])
         if request is not None and has_flattened_params:
@@ -1068,7 +1319,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1092,6 +1348,22 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the product does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_delete_product():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.DeleteProductRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                await client.delete_product(request=request)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.DeleteProductRequest, dict]):
                 The request object. Request message for the
@@ -1112,7 +1384,7 @@ class ProductSearchAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1154,7 +1426,10 @@ class ProductSearchAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def create_reference_image(
@@ -1191,6 +1466,29 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if bounding_poly contains more than
            10 polygons.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_create_reference_image():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                reference_image = vision_v1p3beta1.ReferenceImage()
+                reference_image.uri = "uri_value"
+
+                request = vision_v1p3beta1.CreateReferenceImageRequest(
+                    parent="parent_value",
+                    reference_image=reference_image,
+                )
+
+                # Make the request
+                response = await client.create_reference_image(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.CreateReferenceImageRequest, dict]):
                 The request object. Request message for the
@@ -1236,7 +1534,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, reference_image, reference_image_id])
         if request is not None and has_flattened_params:
@@ -1278,7 +1576,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1305,6 +1608,22 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the reference image does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_delete_reference_image():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.DeleteReferenceImageRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                await client.delete_reference_image(request=request)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.DeleteReferenceImageRequest, dict]):
                 The request object. Request message for the
@@ -1327,7 +1646,7 @@ class ProductSearchAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1369,7 +1688,10 @@ class ProductSearchAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def list_reference_images(
@@ -1389,6 +1711,26 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if the page_size is greater than
            100, or less than 1.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_list_reference_images():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.ListReferenceImagesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_reference_images(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.ListReferenceImagesRequest, dict]):
                 The request object. Request message for the
@@ -1418,7 +1760,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1459,12 +1801,20 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListReferenceImagesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1485,6 +1835,25 @@ class ProductSearchAsyncClient:
 
         -  Returns NOT_FOUND if the specified image does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_get_reference_image():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.GetReferenceImageRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_reference_image(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.GetReferenceImageRequest, dict]):
                 The request object. Request message for the
@@ -1513,7 +1882,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1554,7 +1923,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1581,6 +1955,23 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the Product or the ProductSet doesn't
            exist.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_add_product_to_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.AddProductToProductSetRequest(
+                    name="name_value",
+                    product="product_value",
+                )
+
+                # Make the request
+                await client.add_product_to_product_set(request=request)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.AddProductToProductSetRequest, dict]):
                 The request object. Request message for the
@@ -1612,7 +2003,7 @@ class ProductSearchAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, product])
         if request is not None and has_flattened_params:
@@ -1653,7 +2044,10 @@ class ProductSearchAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def remove_product_from_product_set(
@@ -1675,6 +2069,23 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND If the Product is not found under the
            ProductSet.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_remove_product_from_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.RemoveProductFromProductSetRequest(
+                    name="name_value",
+                    product="product_value",
+                )
+
+                # Make the request
+                await client.remove_product_from_product_set(request=request)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.RemoveProductFromProductSetRequest, dict]):
                 The request object. Request message for the
@@ -1706,7 +2117,7 @@ class ProductSearchAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, product])
         if request is not None and has_flattened_params:
@@ -1747,7 +2158,10 @@ class ProductSearchAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def list_products_in_product_set(
@@ -1770,6 +2184,26 @@ class ProductSearchAsyncClient:
         -  Returns INVALID_ARGUMENT if page_size is greater than 100 or
            less than 1.
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_list_products_in_product_set():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.ListProductsInProductSetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_products_in_product_set(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.ListProductsInProductSetRequest, dict]):
                 The request object. Request message for the
@@ -1800,7 +2234,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1841,12 +2275,20 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProductsInProductSetAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1875,6 +2317,29 @@ class ProductSearchAsyncClient:
         Storage. For the format of the csv file please see
         [ImportProductSetsGcsSource.csv_file_uri][google.cloud.vision.v1p3beta1.ImportProductSetsGcsSource.csv_file_uri].
 
+        .. code-block:: python
+
+            from google.cloud import vision_v1p3beta1
+
+            async def sample_import_product_sets():
+                # Create a client
+                client = vision_v1p3beta1.ProductSearchAsyncClient()
+
+                # Initialize request argument(s)
+                request = vision_v1p3beta1.ImportProductSetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.import_product_sets(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.vision_v1p3beta1.types.ImportProductSetsRequest, dict]):
                 The request object. Request message for the
@@ -1917,7 +2382,7 @@ class ProductSearchAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, input_config])
         if request is not None and has_flattened_params:
@@ -1957,7 +2422,12 @@ class ProductSearchAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1979,7 +2449,9 @@ class ProductSearchAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-vision",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-vision",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
