@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,6 @@
 #
 from .geometry import (
     BoundingPoly,
-    NormalizedBoundingPoly,
     NormalizedVertex,
     Position,
     Vertex,
@@ -60,8 +59,6 @@ from .image_annotator import (
 from .product_search import (
     ProductSearchParams,
     ProductSearchResults,
-    ProductSearchCategory,
-    ProductSearchResultsView,
 )
 from .product_search_service import (
     AddProductToProductSetRequest,
@@ -102,11 +99,12 @@ from .text_annotation import (
     TextAnnotation,
     Word,
 )
-from .web_detection import WebDetection
+from .web_detection import (
+    WebDetection,
+)
 
 __all__ = (
     "BoundingPoly",
-    "NormalizedBoundingPoly",
     "NormalizedVertex",
     "Position",
     "Vertex",
@@ -147,8 +145,6 @@ __all__ = (
     "Likelihood",
     "ProductSearchParams",
     "ProductSearchResults",
-    "ProductSearchCategory",
-    "ProductSearchResultsView",
     "AddProductToProductSetRequest",
     "BatchOperationMetadata",
     "CreateProductRequest",
