@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,6 @@ __protobuf__ = proto.module(
         "Vertex",
         "NormalizedVertex",
         "BoundingPoly",
-        "NormalizedBoundingPoly",
         "Position",
     },
 )
@@ -40,8 +39,14 @@ class Vertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.INT32, number=1,)
-    y = proto.Field(proto.INT32, number=2,)
+    x = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    y = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class NormalizedVertex(proto.Message):
@@ -56,8 +61,14 @@ class NormalizedVertex(proto.Message):
             Y coordinate.
     """
 
-    x = proto.Field(proto.FLOAT, number=1,)
-    y = proto.Field(proto.FLOAT, number=2,)
+    x = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    y = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 class BoundingPoly(proto.Message):
@@ -70,21 +81,16 @@ class BoundingPoly(proto.Message):
             The bounding polygon normalized vertices.
     """
 
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
+    vertices = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Vertex",
+    )
     normalized_vertices = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="NormalizedVertex",
+        proto.MESSAGE,
+        number=2,
+        message="NormalizedVertex",
     )
-
-
-class NormalizedBoundingPoly(proto.Message):
-    r"""A normalized bounding polygon around a portion of an image.
-
-    Attributes:
-        vertices (Sequence[google.cloud.vision_v1p3beta1.types.NormalizedVertex]):
-            Normalized vertices of the bounding polygon.
-    """
-
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="NormalizedVertex",)
 
 
 class Position(proto.Message):
@@ -102,9 +108,18 @@ class Position(proto.Message):
             Z coordinate (or depth).
     """
 
-    x = proto.Field(proto.FLOAT, number=1,)
-    y = proto.Field(proto.FLOAT, number=2,)
-    z = proto.Field(proto.FLOAT, number=3,)
+    x = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    y = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    z = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
