@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -115,14 +115,36 @@ class Product(proto.Message):
                 bytes.
         """
 
-        key = proto.Field(proto.STRING, number=1,)
-        value = proto.Field(proto.STRING, number=2,)
+        key = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        value = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    description = proto.Field(proto.STRING, number=3,)
-    product_category = proto.Field(proto.STRING, number=4,)
-    product_labels = proto.RepeatedField(proto.MESSAGE, number=5, message=KeyValue,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    product_category = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    product_labels = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=KeyValue,
+    )
 
 
 class ProductSet(proto.Message):
@@ -160,10 +182,24 @@ class ProductSet(proto.Message):
             ProductSet.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    index_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    index_error = proto.Field(proto.MESSAGE, number=4, message=status_pb2.Status,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    index_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    index_error = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=status_pb2.Status,
+    )
 
 
 class ReferenceImage(proto.Message):
@@ -190,17 +226,25 @@ class ReferenceImage(proto.Message):
             field is empty, the system will try to detect
             regions of interest. At most 10 bounding
             polygons will be used.
-            The provided shape is converted into a non-
-            rotated rectangle. Once converted, the small
+            The provided shape is converted into a
+            non-rotated rectangle. Once converted, the small
             edge of the rectangle must be greater than or
             equal to 300 pixels. The aspect ratio must be
             1:4 or less (i.e. 1:3 is ok; 1:5 is not).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    uri = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    uri = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     bounding_polys = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=geometry.BoundingPoly,
+        proto.MESSAGE,
+        number=3,
+        message=geometry.BoundingPoly,
     )
 
 
@@ -223,9 +267,19 @@ class CreateProductRequest(proto.Message):
             cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    product = proto.Field(proto.MESSAGE, number=2, message="Product",)
-    product_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    product = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Product",
+    )
+    product_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListProductsRequest(proto.Message):
@@ -245,9 +299,18 @@ class ListProductsRequest(proto.Message):
             if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListProductsResponse(proto.Message):
@@ -266,8 +329,15 @@ class ListProductsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    products = proto.RepeatedField(proto.MESSAGE, number=1, message="Product",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    products = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Product",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetProductRequest(proto.Message):
@@ -281,7 +351,10 @@ class GetProductRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateProductRequest(proto.Message):
@@ -299,9 +372,15 @@ class UpdateProductRequest(proto.Message):
             ``product_labels``, ``display_name``, and ``description``.
     """
 
-    product = proto.Field(proto.MESSAGE, number=1, message="Product",)
+    product = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Product",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -316,7 +395,10 @@ class DeleteProductRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateProductSetRequest(proto.Message):
@@ -338,9 +420,19 @@ class CreateProductSetRequest(proto.Message):
             cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    product_set = proto.Field(proto.MESSAGE, number=2, message="ProductSet",)
-    product_set_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    product_set = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ProductSet",
+    )
+    product_set_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListProductSetsRequest(proto.Message):
@@ -360,9 +452,18 @@ class ListProductSetsRequest(proto.Message):
             if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListProductSetsResponse(proto.Message):
@@ -381,8 +482,15 @@ class ListProductSetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    product_sets = proto.RepeatedField(proto.MESSAGE, number=1, message="ProductSet",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    product_sets = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="ProductSet",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetProductSetRequest(proto.Message):
@@ -396,7 +504,10 @@ class GetProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/productSets/PRODUCT_SET_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateProductSetRequest(proto.Message):
@@ -413,9 +524,15 @@ class UpdateProductSetRequest(proto.Message):
             ``display_name``.
     """
 
-    product_set = proto.Field(proto.MESSAGE, number=1, message="ProductSet",)
+    product_set = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="ProductSet",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -430,7 +547,10 @@ class DeleteProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/productSets/PRODUCT_SET_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateReferenceImageRequest(proto.Message):
@@ -454,9 +574,19 @@ class CreateReferenceImageRequest(proto.Message):
             characters long. It cannot contain the character ``/``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    reference_image = proto.Field(proto.MESSAGE, number=2, message="ReferenceImage",)
-    reference_image_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reference_image = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ReferenceImage",
+    )
+    reference_image_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListReferenceImagesRequest(proto.Message):
@@ -480,9 +610,18 @@ class ListReferenceImagesRequest(proto.Message):
             Defaults to the first page if not specified.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListReferenceImagesResponse(proto.Message):
@@ -504,10 +643,18 @@ class ListReferenceImagesResponse(proto.Message):
         return self
 
     reference_images = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ReferenceImage",
+        proto.MESSAGE,
+        number=1,
+        message="ReferenceImage",
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    page_size = proto.Field(proto.INT32, number=2,)
-    next_page_token = proto.Field(proto.STRING, number=3,)
 
 
 class GetReferenceImageRequest(proto.Message):
@@ -522,7 +669,10 @@ class GetReferenceImageRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteReferenceImageRequest(proto.Message):
@@ -538,7 +688,10 @@ class DeleteReferenceImageRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class AddProductToProductSetRequest(proto.Message):
@@ -558,8 +711,14 @@ class AddProductToProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    product = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    product = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class RemoveProductFromProductSetRequest(proto.Message):
@@ -579,8 +738,14 @@ class RemoveProductFromProductSetRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOC_ID/products/PRODUCT_ID``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    product = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    product = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListProductsInProductSetRequest(proto.Message):
@@ -601,9 +766,18 @@ class ListProductsInProductSetRequest(proto.Message):
             if any.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListProductsInProductSetResponse(proto.Message):
@@ -622,8 +796,15 @@ class ListProductsInProductSetResponse(proto.Message):
     def raw_page(self):
         return self
 
-    products = proto.RepeatedField(proto.MESSAGE, number=1, message="Product",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    products = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Product",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ImportProductSetsGcsSource(proto.Message):
@@ -707,7 +888,10 @@ class ImportProductSetsGcsSource(proto.Message):
             too large to process (larger than 20MP).
     """
 
-    csv_file_uri = proto.Field(proto.STRING, number=1,)
+    csv_file_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ImportProductSetsInputConfig(proto.Message):
@@ -720,11 +904,15 @@ class ImportProductSetsInputConfig(proto.Message):
             The Google Cloud Storage location for a csv
             file which preserves a list of
             ImportProductSetRequests in each line.
+
             This field is a member of `oneof`_ ``source``.
     """
 
     gcs_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="ImportProductSetsGcsSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="ImportProductSetsGcsSource",
     )
 
 
@@ -742,9 +930,14 @@ class ImportProductSetsRequest(proto.Message):
             requests.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     input_config = proto.Field(
-        proto.MESSAGE, number=2, message="ImportProductSetsInputConfig",
+        proto.MESSAGE,
+        number=2,
+        message="ImportProductSetsInputConfig",
     )
 
 
@@ -771,9 +964,15 @@ class ImportProductSetsResponse(proto.Message):
     """
 
     reference_images = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ReferenceImage",
+        proto.MESSAGE,
+        number=1,
+        message="ReferenceImage",
+    )
+    statuses = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=status_pb2.Status,
     )
-    statuses = proto.RepeatedField(proto.MESSAGE, number=2, message=status_pb2.Status,)
 
 
 class BatchOperationMetadata(proto.Message):
@@ -805,9 +1004,21 @@ class BatchOperationMetadata(proto.Message):
         FAILED = 3
         CANCELLED = 4
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    submit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    submit_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class ProductSetPurgeConfig(proto.Message):
@@ -821,7 +1032,10 @@ class ProductSetPurgeConfig(proto.Message):
             ProductSets, the Product will still be deleted.
     """
 
-    product_set_id = proto.Field(proto.STRING, number=1,)
+    product_set_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PurgeProductsRequest(proto.Message):
@@ -838,10 +1052,12 @@ class PurgeProductsRequest(proto.Message):
         product_set_purge_config (google.cloud.vision_v1p4beta1.types.ProductSetPurgeConfig):
             Specify which ProductSet contains the
             Products to be deleted.
+
             This field is a member of `oneof`_ ``target``.
         delete_orphan_products (bool):
             If delete_orphan_products is true, all Products that are not
             in any ProductSet will be deleted.
+
             This field is a member of `oneof`_ ``target``.
         parent (str):
             Required. The project and location in which the Products
@@ -854,11 +1070,24 @@ class PurgeProductsRequest(proto.Message):
     """
 
     product_set_purge_config = proto.Field(
-        proto.MESSAGE, number=2, oneof="target", message="ProductSetPurgeConfig",
+        proto.MESSAGE,
+        number=2,
+        oneof="target",
+        message="ProductSetPurgeConfig",
+    )
+    delete_orphan_products = proto.Field(
+        proto.BOOL,
+        number=3,
+        oneof="target",
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    force = proto.Field(
+        proto.BOOL,
+        number=4,
     )
-    delete_orphan_products = proto.Field(proto.BOOL, number=3, oneof="target",)
-    parent = proto.Field(proto.STRING, number=1,)
-    force = proto.Field(proto.BOOL, number=4,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
