@@ -21,13 +21,16 @@ import os
 import time
 import unittest
 
-import google.api_core.exceptions
-from google.cloud import exceptions
+import pytest
+
+from google.api_core import exceptions
 from google.cloud import storage
 from google.cloud import vision
+from google.protobuf import field_mask_pb2 as field_mask
 
 from test_utils.retry import RetryErrors
 from test_utils.system import unique_resource_id
+from test_utils.vpcsc_config import vpcsc_config
 
 
 _SYS_TESTS_DIR = os.path.realpath(os.path.dirname(__file__))
@@ -35,8 +38,7 @@ FACE_FILE = os.path.join(_SYS_TESTS_DIR, "data", "faces.jpg")
 LOGO_FILE = os.path.join(_SYS_TESTS_DIR, "data", "logo.png")
 PDF_FILE = os.path.join(_SYS_TESTS_DIR, "data", "pdf_test.pdf")
 PROJECT_ID = os.environ.get("PROJECT_ID")
-PROJECT_OUTSIDE = os.environ.get("GOOGLE_CLOUD_TESTS_VPCSC_OUTSIDE_PERIMETER_PROJECT")
-BUCKET_OUTSIDE = os.environ.get("GOOGLE_CLOUD_TESTS_VPCSC_OUTSIDE_PERIMETER_BUCKET")
+_VPCSC_PROHIBITED_MESSAGE = "Request is prohibited by organization's policy"
 
 
 class VisionSystemTestBase(unittest.TestCase):
@@ -81,7 +83,7 @@ class TestVisionClientLogo(VisionSystemTestBase):
 
         # Check to ensure we got what we expect.
         assert len(response.logo_annotations) == 1
-        assert response.logo_annotations[0].description == "google"
+        assert response.logo_annotations[0].description.lower() == "google"
 
     def test_detect_logos_file_handler(self):
         # Get a file handler, and make the request using it.
@@ -90,7 +92,7 @@ class TestVisionClientLogo(VisionSystemTestBase):
 
         # Check to ensure we got what we expect.
         assert len(response.logo_annotations) == 1
-        assert response.logo_annotations[0].description == "google"
+        assert response.logo_annotations[0].description.lower() == "google"
 
     def test_detect_logos_filename(self):
         # Make the request with the filename directly.
@@ -98,7 +100,7 @@ class TestVisionClientLogo(VisionSystemTestBase):
 
         # Check to ensure we got what we expect.
         assert len(response.logo_annotations) == 1
-        assert response.logo_annotations[0].description == "google"
+        assert response.logo_annotations[0].description.lower() == "google"
 
     def test_detect_logos_gcs(self):
         # Upload the image to Google Cloud Storage.
@@ -121,7 +123,7 @@ class TestVisionClientLogo(VisionSystemTestBase):
 
         # Check the response.
         assert len(response.logo_annotations) == 1
-        assert response.logo_annotations[0].description == "google"
+        assert response.logo_annotations[0].description.lower() == "google"
 
     def test_detect_logos_async(self):
         # Upload the image to Google Cloud Storage.
@@ -140,14 +142,16 @@ class TestVisionClientLogo(VisionSystemTestBase):
                     )
                 }
             },
-            "features": [{"type": vision.enums.Feature.Type.LOGO_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.LOGO_DETECTION}],
         }
         method_name = "test_detect_logos_async"
         output_gcs_uri_prefix = "gs://{bucket}/{method_name}".format(
             bucket=self.test_bucket.name, method_name=method_name
         )
         output_config = {"gcs_destination": {"uri": output_gcs_uri_prefix}}
-        response = self.client.async_batch_annotate_images([request], output_config)
+        response = self.client.async_batch_annotate_images(
+            requests=[request], output_config=output_config
+        )
 
         # Wait for the operation to complete.
         lro_waiting_seconds = 90
@@ -177,7 +181,7 @@ class TestVisionClientLogo(VisionSystemTestBase):
         assert len(responses) == 1
         logo_annotations = responses[0]["logoAnnotations"]
         assert len(logo_annotations) == 1
-        assert logo_annotations[0]["description"] == "google"
+        assert logo_annotations[0]["description"].lower() == "google"
 
 
 class TestVisionClientFiles(VisionSystemTestBase):
@@ -203,10 +207,10 @@ class TestVisionClientFiles(VisionSystemTestBase):
                 },
                 "mime_type": "application/pdf",
             },
-            "features": [{"type": vision.enums.Feature.Type.DOCUMENT_TEXT_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.DOCUMENT_TEXT_DETECTION}],
             "output_config": {"gcs_destination": {"uri": output_gcs_uri_prefix}},
         }
-        response = self.client.async_batch_annotate_files([request])
+        response = self.client.async_batch_annotate_files(requests=[request])
 
         # Wait for the operation to complete.
         lro_waiting_seconds = 90
@@ -252,9 +256,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
         self.products_to_delete = []
         self.product_sets_to_delete = []
         self.location = "us-west1"
-        self.location_path = self.ps_client.location_path(
-            project=PROJECT_ID, location=self.location
-        )
+        self.location_path = f"projects/{PROJECT_ID}/locations/{self.location}"
 
     def tearDown(self):
         VisionSystemTestBase.tearDown(self)
@@ -276,7 +278,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_create_product_set(self):
         # Create a ProductSet.
-        product_set = vision.types.ProductSet(display_name="display name")
+        product_set = vision.ProductSet(display_name="display name")
         product_set_id = "set" + unique_resource_id()
         product_set_path = self.ps_client.product_set_path(
             project=PROJECT_ID, location=self.location, product_set=product_set_id
@@ -292,7 +294,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_get_product_set(self):
         # Create a ProductSet.
-        product_set = vision.types.ProductSet(display_name="display name")
+        product_set = vision.ProductSet(display_name="display name")
         product_set_id = "set" + unique_resource_id()
         product_set_path = self.ps_client.product_set_path(
             project=PROJECT_ID, location=self.location, product_set=product_set_id
@@ -310,7 +312,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_list_product_sets(self):
         # Create a ProductSet.
-        product_set = vision.types.ProductSet(display_name="display name")
+        product_set = vision.ProductSet(display_name="display name")
         product_set_id = "set" + unique_resource_id()
         product_set_path = self.ps_client.product_set_path(
             project=PROJECT_ID, location=self.location, product_set=product_set_id
@@ -334,7 +336,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_update_product_set(self):
         # Create a ProductSet.
-        product_set = vision.types.ProductSet(display_name="display name")
+        product_set = vision.ProductSet(display_name="display name")
         product_set_id = "set" + unique_resource_id()
         product_set_path = self.ps_client.product_set_path(
             project=PROJECT_ID, location=self.location, product_set=product_set_id
@@ -348,10 +350,10 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
         self.assertEqual(response.name, product_set_path)
         # Update the ProductSet.
         new_display_name = "updated name"
-        updated_product_set_request = vision.types.ProductSet(
+        updated_product_set_request = vision.ProductSet(
             name=product_set_path, display_name=new_display_name
         )
-        update_mask = vision.types.FieldMask(paths=["display_name"])
+        update_mask = field_mask.FieldMask(paths=["display_name"])
         updated_product_set = self.ps_client.update_product_set(
             product_set=updated_product_set_request, update_mask=update_mask
         )
@@ -359,7 +361,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_create_product(self):
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -375,7 +377,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_get_product(self):
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -393,7 +395,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_update_product(self):
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -407,10 +409,10 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
         self.assertEqual(response.name, product_path)
         # Update the Product.
         new_display_name = "updated product name"
-        updated_product_request = vision.types.Product(
+        updated_product_request = vision.Product(
             name=product_path, display_name=new_display_name
         )
-        update_mask = vision.types.FieldMask(paths=["display_name"])
+        update_mask = field_mask.FieldMask(paths=["display_name"])
         updated_product = self.ps_client.update_product(
             product=updated_product_request, update_mask=update_mask
         )
@@ -418,7 +420,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_list_products(self):
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -440,7 +442,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_list_products_in_product_set(self):
         # Create a ProductSet.
-        product_set = vision.types.ProductSet(display_name="display name")
+        product_set = vision.ProductSet(display_name="display name")
         product_set_id = "set" + unique_resource_id()
         product_set_path = self.ps_client.product_set_path(
             project=PROJECT_ID, location=self.location, product_set=product_set_id
@@ -453,7 +455,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
         self.product_sets_to_delete.append(response.name)
         self.assertEqual(response.name, product_set_path)
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -482,7 +484,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
 
     def test_reference_image(self):
         # Create a Product.
-        product = vision.types.Product(
+        product = vision.Product(
             display_name="product display name", product_category="apparel"
         )
         product_id = "product" + unique_resource_id()
@@ -506,7 +508,7 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
             product=product_id,
             reference_image=reference_image_id,
         )
-        reference_image = vision.types.ReferenceImage(uri=gcs_uri)
+        reference_image = vision.ReferenceImage(uri=gcs_uri)
         response = self.ps_client.create_reference_image(
             parent=product_path,
             reference_image=reference_image,
@@ -594,12 +596,12 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
         blob.upload_from_string(csv_data)
 
         # Make the import_product_sets request.
-        gcs_source = vision.types.ImportProductSetsGcsSource(
+        gcs_source = vision.ImportProductSetsGcsSource(
             csv_file_uri="gs://{bucket}/{blob}".format(
                 bucket=self.test_bucket.name, blob=csv_filename
             )
         )
-        input_config = vision.types.ImportProductSetsInputConfig(gcs_source=gcs_source)
+        input_config = vision.ImportProductSetsInputConfig(gcs_source=gcs_source)
         response = self.ps_client.import_product_sets(
             parent=self.location_path, input_config=input_config
         )
@@ -617,263 +619,185 @@ class TestVisionClientProductSearch(VisionSystemTestBase):
             self.assertEqual(status.code, grpc.StatusCode.OK.value[0])
 
 
-@unittest.skipUnless(
-    PROJECT_OUTSIDE,
-    "GOOGLE_CLOUD_TESTS_VPCSC_OUTSIDE_PERIMETER_PROJECT not set in environment.",
-)
+@vpcsc_config.skip_unless_outside_project
 class TestVisionClientProductSearchVpcsc(VisionSystemTestBase):
     # Tests to verify ProductSearch is blocked by VPC SC when trying to access a resource outside of a secure perimeter.
     def setUp(self):
-        VisionSystemTestBase.setUp(self)
+        super(TestVisionClientProductSearchVpcsc, self).setUp()
+        uniq = unique_resource_id()
         self.location = "us-west1"
-        self.location_path = self.ps_client.location_path(
-            project=PROJECT_OUTSIDE, location=self.location
+        self.location_path = (
+            f"projects/{vpcsc_config.project_outside}/locations/{self.location}"
+        )
+        self.product_set_id = product_set_id = "set" + uniq
+        self.product_set_path = self.ps_client.product_set_path(
+            project=vpcsc_config.project_outside,
+            location=self.location,
+            product_set=product_set_id,
+        )
+        self.product_id = "product" + uniq
+        self.product_path = self.ps_client.product_path(
+            project=vpcsc_config.project_outside,
+            location=self.location,
+            product=self.product_id,
+        )
+        self.reference_image_id = "reference_image" + uniq
+        self.reference_image_path = self.ps_client.reference_image_path(
+            project=vpcsc_config.project_outside,
+            location=self.location,
+            product=self.product_id,
+            reference_image=self.reference_image_id,
         )
-
-    def _verify_vpc_sc_error(self, call):
-        # Verifies that a VPC SC 403 error is raised.
-        try:
-            # call() should raise a PermissionDenied exception.
-            results = call()
-            # Some of the tests get a GRPCIterator object, which won't raise an exception until iteration starts.
-            for result in results:
-                break
-        except google.api_core.exceptions.PermissionDenied as e:
-            # Verify the PermissionDenied exception was due to VPC SC.
-            self.assertEqual(
-                e.message, "Request is prohibited by organization's policy"
-            )
-            return
-        except Exception as e:
-            self.fail("Unexpected exception raised: {}".format(e))
-        self.fail("No exception raised.")
 
     def test_create_product_set_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.create_product_set(
-                parent=self.location_path, product_set={}, product_set_id=product_set_id
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.create_product_set(
+                parent=self.location_path,
+                product_set={},
+                product_set_id=self.product_set_id,
             )
-        )
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_get_product_set_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        product_set_path = self.ps_client.product_set_path(
-            project=PROJECT_OUTSIDE, location=self.location, product_set=product_set_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.get_product_set(name=product_set_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.get_product_set(name=self.product_set_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_delete_product_set_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        product_set_path = self.ps_client.product_set_path(
-            project=PROJECT_OUTSIDE, location=self.location, product_set=product_set_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.delete_product_set(name=product_set_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.delete_product_set(name=self.product_set_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_list_product_sets_blocked(self):
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.list_product_sets(parent=self.location_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            list(self.ps_client.list_product_sets(parent=self.location_path))
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_update_product_set_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        product_set_path = self.ps_client.product_set_path(
-            project=PROJECT_OUTSIDE, location=self.location, product_set=product_set_id
-        )
-        product_set = vision.types.ProductSet(name=product_set_path)
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.update_product_set(product_set=product_set)
-        )
+        product_set = vision.ProductSet(name=self.product_set_path)
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.update_product_set(product_set=product_set)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_create_product_blocked(self):
-        product_id = "product" + unique_resource_id()
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.create_product(
-                parent=self.location_path, product={}, product_id=product_id
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.create_product(
+                parent=self.location_path, product={}, product_id=self.product_id
             )
-        )
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_get_product_blocked(self):
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        self._verify_vpc_sc_error(lambda: self.ps_client.get_product(name=product_path))
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.get_product(name=self.product_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_delete_product_blocked(self):
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.delete_product(name=product_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.delete_product(name=self.product_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_update_product_blocked(self):
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        product = vision.types.Product(name=product_path)
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.update_product(product=product)
-        )
+        product = vision.Product(name=self.product_path)
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.update_product(product=product)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_list_products_blocked(self):
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.list_products(parent=self.location_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            list(self.ps_client.list_products(parent=self.location_path))
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_list_products_in_product_set_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        product_set_path = self.ps_client.product_set_path(
-            project=PROJECT_OUTSIDE, location=self.location, product_set=product_set_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.list_products_in_product_set(name=product_set_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            list(
+                self.ps_client.list_products_in_product_set(name=self.product_set_path)
+            )
 
-    def test_add_remove_product_blocked(self):
-        product_set_id = "set" + unique_resource_id()
-        product_set_path = self.ps_client.product_set_path(
-            project=PROJECT_OUTSIDE, location=self.location, product_set=product_set_id
-        )
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.add_product_to_product_set(
-                name=product_set_path, product=product_path
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
+
+    def test_add_product_to_product_set_blocked(self):
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.add_product_to_product_set(
+                name=self.product_set_path, product=self.product_path
             )
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.remove_product_from_product_set(
-                name=product_set_path, product=product_path
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
+
+    def test_remove_product_from_product_set_blocked(self):
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.remove_product_from_product_set(
+                name=self.product_set_path, product=self.product_path
             )
-        )
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_create_reference_image_blocked(self):
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        reference_image_id = "reference_image" + unique_resource_id()
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.create_reference_image(
-                parent=product_path,
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.create_reference_image(
+                parent=self.product_path,
                 reference_image={},
-                reference_image_id=reference_image_id,
+                reference_image_id=self.reference_image_id,
             )
-        )
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_get_reference_image_blocked(self):
-        product_id = "product" + unique_resource_id()
-        reference_image_id = "reference_image" + unique_resource_id()
-        reference_image_path = self.ps_client.reference_image_path(
-            project=PROJECT_OUTSIDE,
-            location=self.location,
-            product=product_id,
-            reference_image=reference_image_id,
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.get_reference_image(name=reference_image_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.get_reference_image(name=self.reference_image_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_delete_reference_image_blocked(self):
-        product_id = "product" + unique_resource_id()
-        reference_image_id = "reference_image" + unique_resource_id()
-        reference_image_path = self.ps_client.reference_image_path(
-            project=PROJECT_OUTSIDE,
-            location=self.location,
-            product=product_id,
-            reference_image=reference_image_id,
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.delete_reference_image(name=reference_image_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            self.ps_client.delete_reference_image(name=self.reference_image_path)
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
     def test_list_reference_images_blocked(self):
-        product_id = "product" + unique_resource_id()
-        product_path = self.ps_client.product_path(
-            project=PROJECT_OUTSIDE, location=self.location, product=product_id
-        )
-        self._verify_vpc_sc_error(
-            lambda: self.ps_client.list_reference_images(parent=product_path)
-        )
+        with pytest.raises(exceptions.PermissionDenied) as exc:
+            list(self.ps_client.list_reference_images(parent=self.product_path))
+
+        assert exc.value.message.startswith(_VPCSC_PROHIBITED_MESSAGE)
 
 
-@unittest.skipUnless(
-    BUCKET_OUTSIDE,
-    "GOOGLE_CLOUD_TESTS_VPCSC_OUTSIDE_PERIMETER_BUCKET not set in environment.",
-)
+@vpcsc_config.skip_unless_inside_vpcsc
 class TestVisionClientVpcsc(VisionSystemTestBase):
     # Tests to verify Vision API methods are blocked by VPC SC when trying to access a gcs resource outside of a secure perimeter.
     def setUp(self):
-        VisionSystemTestBase.setUp(self)
+        super(TestVisionClientVpcsc, self).setUp()
         self.blocked_file = "LC08/01_$folder$"
         self.gcs_uri_blocked_file = "gs://{bucket}/{file}".format(
-            bucket=BUCKET_OUTSIDE, file=self.blocked_file
+            bucket=vpcsc_config.bucket_outside, file=self.blocked_file
         )
-        self._verify_vpc_sc_blocks_gcs_bucket()
         self.gcs_read_error_message = "Error opening file: gs://"
-        self.gcs_write_error_message = "Error writing final output to: gs://"
-
-    def _verify_vpc_sc_blocks_gcs_bucket(self):
-        # Verifies that a VPC SC 403 error is raised when trying to access a bucket in gcs that is outside the perimeter.
-        try:
-            storage_client = storage.Client()
-            outside_bucket = storage_client.get_bucket(BUCKET_OUTSIDE)
-            blob = outside_bucket.blob(self.blocked_file)
-            blob.download_as_string()
-        except google.api_core.exceptions.Forbidden as e:
-            # Verify the Forbidden exception was due to VPC SC.
-            vpc_sc_error_message = "Request violates VPC Service Controls."
-            self.assertTrue(
-                vpc_sc_error_message in e.message,
-                "'{}' not in '{}'".format(vpc_sc_error_message, e.message),
-            )
-            return
-        except Exception as e:
-            self.fail(
-                "Unexpected exception raised while accessing gcs bucket: {}".format(e)
-            )
-        self.fail(
-            "No exception raised when accessing gcs bucket: {}".format(
-                self.gcs_uri_blocked_file
-            )
+        self.gcs_write_error_message = "Error writing final output to"
+        self.location = "us-west1"
+        self.location_path = (
+            f"projects/{vpcsc_config.project_inside}/locations/{self.location}"
         )
 
-    @unittest.skipUnless(PROJECT_ID, "PROJECT_ID not set in environment.")
     def test_import_product_sets_blocked(self):
         # The csv file is outside the secure perimeter.
-        gcs_source = vision.types.ImportProductSetsGcsSource(
+        gcs_source = vision.ImportProductSetsGcsSource(
             csv_file_uri=self.gcs_uri_blocked_file
         )
-        input_config = vision.types.ImportProductSetsInputConfig(gcs_source=gcs_source)
-        # Use a valid Project ID.
-        location_path = self.ps_client.location_path(
-            project=PROJECT_ID, location="us-west1"
-        )
-        try:
-            # A 403 exception should be raised because the csv file is not accessible due to VPC SC.
+        input_config = vision.ImportProductSetsInputConfig(gcs_source=gcs_source)
+        with pytest.raises(exceptions.Forbidden) as exc:
             self.ps_client.import_product_sets(
-                parent=location_path, input_config=input_config
+                parent=self.location_path, input_config=input_config
             )
-        except google.api_core.exceptions.Forbidden as e:
-            # Verify the 403 error was due to reading the file in gcs.
-            self.assertTrue(
-                self.gcs_read_error_message in e.message,
-                "'{}' not in '{}'".format(self.gcs_read_error_message, e.message),
-            )
-            return
-        except Exception as e:
-            self.fail("Unexpected exception raised: {}".format(e))
-        self.fail("No exception raised.")
+
+        assert self.gcs_read_error_message in exc.value.message
 
     def test_async_batch_annotate_files_read_blocked(self):
         # Make the request.
@@ -887,22 +811,13 @@ class TestVisionClientVpcsc(VisionSystemTestBase):
                 "gcs_source": {"uri": self.gcs_uri_blocked_file},
                 "mime_type": "application/pdf",
             },
-            "features": [{"type": vision.enums.Feature.Type.DOCUMENT_TEXT_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.DOCUMENT_TEXT_DETECTION}],
             "output_config": {"gcs_destination": {"uri": output_gcs_uri_prefix}},
         }
-        try:
-            # A 403 exception should be raised.
-            self.client.async_batch_annotate_files([request])
-        except google.api_core.exceptions.Forbidden as e:
-            # Verify the 403 error was due to reading the file in gcs.
-            self.assertTrue(
-                self.gcs_read_error_message in e.message,
-                "'{}' not in '{}'".format(self.gcs_read_error_message, e.message),
-            )
-            return
-        except Exception as e:
-            self.fail("Unexpected exception raised: {}".format(e))
-        self.fail("No exception raised.")
+        with pytest.raises(exceptions.Forbidden) as exc:
+            self.client.async_batch_annotate_files(requests=[request])
+
+        assert self.gcs_read_error_message in exc.value.message
 
     def test_async_batch_annotate_files_write_blocked(self):
         # Upload the image to Google Cloud Storage.
@@ -911,10 +826,11 @@ class TestVisionClientVpcsc(VisionSystemTestBase):
         self.to_delete_by_case.append(blob)
         with io.open(PDF_FILE, "rb") as image_file:
             blob.upload_from_file(image_file)
+
         method_name = "test_async_batch_annotate_files_write_blocked"
         # Write the result to a bucket outside of the secure perimeter.
         output_gcs_uri_prefix = "gs://{bucket}/{method_name}".format(
-            bucket=BUCKET_OUTSIDE, method_name=method_name
+            bucket=vpcsc_config.bucket_outside, method_name=method_name
         )
         request = {
             "input_config": {
@@ -925,99 +841,86 @@ class TestVisionClientVpcsc(VisionSystemTestBase):
                 },
                 "mime_type": "application/pdf",
             },
-            "features": [{"type": vision.enums.Feature.Type.DOCUMENT_TEXT_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.DOCUMENT_TEXT_DETECTION}],
             "output_config": {"gcs_destination": {"uri": output_gcs_uri_prefix}},
         }
-        response = self.client.async_batch_annotate_files([request])
+        response = self.client.async_batch_annotate_files(requests=[request])
+
         # Wait for the operation to complete.
         lro_waiting_seconds = 90
         start_time = time.time()
         while not response.done() and (time.time() - start_time) < lro_waiting_seconds:
             time.sleep(1)
-        if not response.done():
-            self.fail(
-                "{method_name} timed out after {lro_waiting_seconds} seconds".format(
-                    method_name=method_name, lro_waiting_seconds=lro_waiting_seconds
-                )
-            )
+        assert response.done
+
         # Verify there was an error writing to the output bucket.
         error = response.operation.error
         assert error.code == 7
-        assert self.gcs_write_error_message in error.message, "'{}' not in '{}'".format(
-            self.gcs_write_error_message, error.message
-        )
+        assert self.gcs_write_error_message in error.message
 
     def test_async_batch_annotate_images_read_blocked(self):
-        # Make the request. The input file is in a gcs bucket that is outside of the secure perimeter.
         request = {
             "image": {"source": {"image_uri": self.gcs_uri_blocked_file}},
-            "features": [{"type": vision.enums.Feature.Type.LOGO_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.LOGO_DETECTION}],
         }
         method_name = "test_async_batch_annotate_images_read_blocked"
         output_gcs_uri_prefix = "gs://{bucket}/{method_name}".format(
             bucket=self.test_bucket.name, method_name=method_name
         )
         output_config = {"gcs_destination": {"uri": output_gcs_uri_prefix}}
-        response = self.client.async_batch_annotate_images([request], output_config)
+        response = self.client.async_batch_annotate_images(
+            requests=[request], output_config=output_config
+        )
         # Wait for the operation to complete.
         lro_waiting_seconds = 90
         start_time = time.time()
         while not response.done() and (time.time() - start_time) < lro_waiting_seconds:
             time.sleep(1)
-        if not response.done():
-            self.fail(
-                "{method_name} timed out after {lro_waiting_seconds} seconds".format(
-                    method_name=method_name, lro_waiting_seconds=lro_waiting_seconds
-                )
-            )
+        assert response.done()
+
         # Make sure getting the result is not an error.
         response.result()
-        # There should be exactly 1 output file in gcs at the prefix output_gcs_uri_prefix.
         blobs = list(self.test_bucket.list_blobs(prefix=method_name))
         assert len(blobs) == 1
         blob = blobs[0]
+
         # Download the output file.
         result_str = blob.download_as_string().decode("utf8")
         result = json.loads(result_str)
         responses = result["responses"]
         assert len(responses) == 1
+
         # Verify the read error.
         error = responses[0]["error"]
         assert error["code"] == 7
-        assert (
-            self.gcs_read_error_message in error["message"]
-        ), "'{}' not in '{}'".format(self.gcs_read_error_message, error["message"])
+        assert self.gcs_read_error_message in error["message"]
 
     def test_async_batch_annotate_images_write_blocked(self):
-        # Make the request.
         request = {
             "image": {"source": {"image_uri": self.gcs_uri_blocked_file}},
-            "features": [{"type": vision.enums.Feature.Type.LOGO_DETECTION}],
+            "features": [{"type_": vision.Feature.Type.LOGO_DETECTION}],
         }
         method_name = "test_async_batch_annotate_images_write_blocked"
+
         # Write the result to a bucket outside of the secure perimeter.
         output_gcs_uri_prefix = "gs://{bucket}/{method_name}".format(
-            bucket=BUCKET_OUTSIDE, method_name=method_name
+            bucket=vpcsc_config.bucket_outside, method_name=method_name
         )
         output_config = {"gcs_destination": {"uri": output_gcs_uri_prefix}}
-        response = self.client.async_batch_annotate_images([request], output_config)
+        response = self.client.async_batch_annotate_images(
+            requests=[request], output_config=output_config
+        )
         # Wait for the operation to complete.
         lro_waiting_seconds = 90
         start_time = time.time()
         while not response.done() and (time.time() - start_time) < lro_waiting_seconds:
             time.sleep(1)
-        if not response.done():
-            self.fail(
-                "{method_name} timed out after {lro_waiting_seconds} seconds".format(
-                    method_name=method_name, lro_waiting_seconds=lro_waiting_seconds
-                )
-            )
+        assert response.done()
+
         # Verify there was an error writing to the output bucket.
         error = response.operation.error
         assert error.code == 7
-        assert self.gcs_write_error_message in error.message, "'{}' not in '{}'".format(
-            self.gcs_write_error_message, error.message
-        )
+        assert self.gcs_write_error_message in error.message
 
     def test_batch_annotate_images_read_blocked(self):
         response = self.client.logo_detection(
@@ -1025,6 +928,4 @@ class TestVisionClientVpcsc(VisionSystemTestBase):
         )
         error = response.error
         assert error.code == 7
-        assert self.gcs_read_error_message in error.message, "'{}' not in '{}'".format(
-            self.gcs_read_error_message, error.message
-        )
+        assert self.gcs_read_error_message in error.message
